@@ -1,5 +1,13 @@
+#include "libexslt/libexslt.h"
+
 #include <libxml/xmlversion.h>
 
+#if defined(WIN32) && !defined (__CYGWIN__)
+#include <win32config.h>
+#else
+#include "config.h"
+#endif
+
 #if defined(WIN32) && defined(_MSC_VER)
 #include <libxslt/xsltwin32config.h>
 #else
